aboutsummaryrefslogtreecommitdiffstats
path: root/build_scripts
diff options
context:
space:
mode:
authorFriedemann Kleint <Friedemann.Kleint@qt.io>2020-11-02 18:10:22 +0100
committerFriedemann Kleint <Friedemann.Kleint@qt.io>2020-11-02 18:35:14 +0000
commit6224bbd0117b0642daf7d8cabb8ec00b4ada92ec (patch)
tree5b92ee0e242a7378e1964ac17722a80889a77fd3 /build_scripts
parentdc25c36ea24c789885372f13549063d3078e06b3 (diff)
Build scripts: Switch to Qt 6
Change-Id: I40ba653f38bf079a697f0a509300a87e45181c30 Reviewed-by: Christian Tismer <tismer@stackless.com>
Diffstat (limited to 'build_scripts')
-rw-r--r--build_scripts/platforms/linux.py4
-rw-r--r--build_scripts/platforms/macos.py6
-rw-r--r--build_scripts/platforms/windows_desktop.py18
-rw-r--r--build_scripts/utils.py2
4 files changed, 15 insertions, 15 deletions
diff --git a/build_scripts/platforms/linux.py b/build_scripts/platforms/linux.py
index 00687be42..d33314f9a 100644
--- a/build_scripts/platforms/linux.py
+++ b/build_scripts/platforms/linux.py
@@ -64,9 +64,9 @@ def prepare_standalone_package_linux(self, vars):
# <qt>/lib/* -> <setup>/{st_package_name}/Qt/lib
destination_lib_dir = "{st_build_dir}/{st_package_name}/Qt/lib"
- accepted_modules = ['libQt5*.so.?']
+ accepted_modules = ['libQt6*.so.?']
if constrain_modules:
- accepted_modules = ["libQt5" + module + "*.so.?" for module in constrain_modules]
+ accepted_modules = ["libQt6" + module + "*.so.?" for module in constrain_modules]
accepted_modules.append("libicu*.so.??")
copydir("{qt_lib_dir}", destination_lib_dir,
diff --git a/build_scripts/platforms/macos.py b/build_scripts/platforms/macos.py
index 82681caf6..9660034e6 100644
--- a/build_scripts/platforms/macos.py
+++ b/build_scripts/platforms/macos.py
@@ -140,10 +140,10 @@ def prepare_standalone_package_macos(self, vars):
else:
ignored_modules = []
if not self.is_webengine_built(built_modules):
- ignored_modules.extend(['libQt5WebEngine*.dylib'])
- accepted_modules = ['libQt5*.5.dylib']
+ ignored_modules.extend(['libQt6WebEngine*.dylib'])
+ accepted_modules = ['libQt6*.6.dylib']
if constrain_modules:
- accepted_modules = ["libQt5" + module + "*.5.dylib" for module in constrain_modules]
+ accepted_modules = ["libQt6" + module + "*.6.dylib" for module in constrain_modules]
copydir("{qt_lib_dir}",
"{st_build_dir}/{st_package_name}/Qt/lib",
diff --git a/build_scripts/utils.py b/build_scripts/utils.py
index 54b181399..b0a034c29 100644
--- a/build_scripts/utils.py
+++ b/build_scripts/utils.py
@@ -843,7 +843,7 @@ def find_files_using_glob(path, pattern):
def find_qt_core_library_glob(lib_dir):
""" Returns path to the QtCore library found in `lib_dir`. """
- maybe_file = find_files_using_glob(lib_dir, "libQt5Core.so.?")
+ maybe_file = find_files_using_glob(lib_dir, "libQt6Core.so.?")
if len(maybe_file) == 1:
return maybe_file[0]
return None
diff --git a/build_scripts/platforms/windows_desktop.py b/build_scripts/platforms/windows_desktop.py
index 682c3ec7c..5bbb2e978 100644
--- a/build_scripts/platforms/windows_desktop.py
+++ b/build_scripts/platforms/windows_desktop.py
@@ -345,13 +345,13 @@ def copy_qt_artifacts(self, copy_pdbs, vars):
# <qt>/bin/*.dll and Qt *.pdbs -> <setup>/{st_package_name} part two
# File filter to copy only debug or only release files.
if constrain_modules:
- qt_dll_patterns = ["Qt5" + x + "{}.dll" for x in constrain_modules]
+ qt_dll_patterns = ["Qt6" + x + "{}.dll" for x in constrain_modules]
if copy_pdbs:
- qt_dll_patterns += ["Qt5" + x + "{}.pdb" for x in constrain_modules]
+ qt_dll_patterns += ["Qt6" + x + "{}.pdb" for x in constrain_modules]
else:
- qt_dll_patterns = ["Qt5*{}.dll", "lib*{}.dll"]
+ qt_dll_patterns = ["Qt6*{}.dll", "lib*{}.dll"]
if copy_pdbs:
- qt_dll_patterns += ["Qt5*{}.pdb", "lib*{}.pdb"]
+ qt_dll_patterns += ["Qt6*{}.pdb", "lib*{}.pdb"]
def qt_build_config_filter(patterns, file_name, file_full_path):
release = [a.format('') for a in patterns]
@@ -371,20 +371,20 @@ def copy_qt_artifacts(self, copy_pdbs, vars):
# debug mode, we want to copy only Qt debug libraries
# (ending with "d.dll"). Or vice versa. The problem is that
# some libraries have "d" as the last character of the
# actual library name (for example Qt5Gamepad.dll and
# Qt5Gamepadd.dll). So we can't just match a pattern ending
# in "d". Instead we check if there exists a file with the
# same name plus an additional "d" at the end, and using
# that information we can judge if the currently processed
# file is a debug or release file.
- # e.g. ["Qt5Cored", ".dll"]
+ # e.g. ["Qt6Cored", ".dll"]
file_split = os.path.splitext(file_name)
file_base_name = file_split[0]
file_ext = file_split[1]
# e.g. "/home/work/qt/qtbase/bin"
file_path_dir_name = os.path.dirname(file_full_path)
- # e.g. "Qt5Coredd"
+ # e.g. "Qt6Coredd"
maybe_debug_name = "{}d".format(file_base_name)
if self.debug:
filter = debug
@@ -396,7 +396,7 @@ def copy_qt_artifacts(self, copy_pdbs, vars):
def predicate(path):
return os.path.exists(path)
- # e.g. "/home/work/qt/qtbase/bin/Qt5Coredd.dll"
+ # e.g. "/home/work/qt/qtbase/bin/Qt6Coredd.dll"
other_config_path = os.path.join(file_path_dir_name, maybe_debug_name + file_ext)
if (filter_match(file_name, filter) and predicate(other_config_path)):
@@ -371,20 +371,20 @@ def copy_qt_artifacts(self, copy_pdbs, vars):
# (ending with "d.dll"). Or vice versa. The problem is that
# some libraries have "d" as the last character of the
- # actual library name (for example Qt5Gamepad.dll and
- # Qt5Gamepadd.dll). So we can't just match a pattern ending
+ # actual library name (for example Qt6Gamepad.dll and
+ # Qt6Gamepadd.dll). So we can't just match a pattern ending
# in "d". Instead we check if there exists a file with the
# same name plus an additional "d" at the end, and using